summaryrefslogtreecommitdiffstats
path: root/smb4k/configdlg/smb4kauthoptions.h
diff options
context:
space:
mode:
Diffstat (limited to 'smb4k/configdlg/smb4kauthoptions.h')
-rw-r--r--smb4k/configdlg/smb4kauthoptions.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/smb4k/configdlg/smb4kauthoptions.h b/smb4k/configdlg/smb4kauthoptions.h
index 26b8c36..f15cdbf 100644
--- a/smb4k/configdlg/smb4kauthoptions.h
+++ b/smb4k/configdlg/smb4kauthoptions.h
@@ -65,12 +65,12 @@ class Smb4KAuthOptions : public TQWidget
protected slots:
/**
* This slot manages the toggling of the KWallet support button in the
* Authentication tab.
*
* @param state The toggle state
*/
- void slotKWalletButtonState( int state );
+ void slotTDEWalletButtonState( int state );
/**
* This slot manages the toggling of the default authentication button.
*
@@ -65,12 +65,12 @@ class Smb4KAuthOptions : public TQWidget
protected slots:
/**
- * This slot manages the toggling of the KWallet support button in the
+ * This slot manages the toggling of the TDEWallet support button in the
* Authentication tab.
*